==> jekyll-activity-pub-0.1.0rc4.gem: lib/jekyll/activity_pub/activity.rb <==
# frozen_string_literal: true

require 'jekyll/page'
require_relative 'helper'
require_relative 'document'
require_relative 'notifier'

module Jekyll
  module ActivityPub
    # Represents a post on ActivityPub
    class Activity < Jekyll::Page
      include Helper

      # @param :doc [Jekyll::Document]
      attr_reader :doc

      # @param :actor [Jekyll::ActivityPub::Actor]
      attr_reader :actor

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :actor [Jekyll::ActivityPub::Actor]
      # @param :doc [Jekyll::Document]
      # @param :base [String]
      # @param :dir [String]
      # @param :name [String]
      def initialize(site, actor, doc, base = '', dir = '', name = 'index.jsonld')
        @doc = doc
        @context = StubContext.new(registers: { site: site })
        @actor = actor

        super(site, base, dir, name)

        trigger_hooks :post_init
      end

      # @return [nil]
      def read_yaml(*)
        self.data = {
          '@context' => [
            'https://www.w3.org/ns/activitystreams',
            {
              '@language' => locale,
              'sensitive' => 'as:sensitive'
            }
          ],
          'type' => 'Note',
          'id' => absolute_url(doc.url),
          'summary' => summary,
          'published' => doc.date.xmlschema,
          'attributedTo' => absolute_url(actor.url),
          'to' => [
            'https://www.w3.org/ns/activitystreams#Public'
          ],
          'cc' => [ Notifier.followers_url ],
          'inReplyTo' => doc.data['in_reply_to'],
          'sensitive' => sensitive?,
          'content' => doc.content,
          'contentMap' => {
            locale => doc.content
          },
          'attachment' => attachments,
          'tag' => [],
          'replies' => []
        }

        nil
      end

      private

      # Find summary
      #
      # @return [String,nil]
      def summary
        @summary ||= find_best_value_for(doc.data, 'summary', 'description', 'title')
      end

      # Should it have a content warning?
      def sensitive?
        !!doc.data.fetch('sensitive', false)
      end

      # Find attachments
      #
      # @return [Array]
      def attachments
        @attachments ||= [].tap do |array|
          case (image = doc.data['image'])
          when Hash
            array << Document.new(site, image['path'], image['description'])
          when String
            array << Document.new(site, image, summary)
          end
        end
      end
    end
  end
end

==> jekyll-activity-pub-0.2.1.gem: lib/jekyll/activity_pub/activity.rb <==
# frozen_string_literal: true

require 'jekyll/page'
require_relative 'helper'
require_relative 'document'
require_relative 'notifier'

module Jekyll
  module ActivityPub
    # Represents a post on ActivityPub
    class Activity < Jekyll::Page
      include Helper

      # @param :doc [Jekyll::Document]
      attr_reader :doc

      # @param :actor [Jekyll::ActivityPub::Actor]
      attr_reader :actor

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :actor [Jekyll::ActivityPub::Actor]
      # @param :doc [Jekyll::Document]
      # @param :base [String]
      # @param :dir [String]
      # @param :name [String]
      def initialize(site, actor, doc, base = '', dir = '', name = 'index.jsonld')
        @doc = doc
        @context = StubContext.new(registers: { site: site })
        @actor = actor

        super(site, base, dir, name)

        trigger_hooks :post_init
      end

      # @return [nil]
      def read_yaml(*)
        self.data = {
          '@context' => [
            'https://www.w3.org/ns/activitystreams',
            {
              '@language' => locale,
              'sensitive' => 'as:sensitive'
            }
          ],
          'type' => 'Note',
          'id' => absolute_url(url),
          'url' => absolute_url(doc.url),
          'summary' => summary,
          'published' => (doc.data['created_at'] || doc.date).xmlschema,
          'updated' => doc.data['last_modified_at']&.xmlschema,
          'attributedTo' => absolute_url(actor.url),
          'to' => [
            'https://www.w3.org/ns/activitystreams#Public'
          ],
          'cc' => [Notifier.followers_url],
          'inReplyTo' => doc.data['in_reply_to'],
          'sensitive' => sensitive?,
          'content' => doc.content,
          'name' => doc.data['title'],
          'contentMap' => {
            locale => doc.content
          },
          'attachment' => attachments,
          'tag' => [],
          'replies' => []
        }

        nil
      end

      private

      # @return [String]
      def content_warning
        @content_warning ||= doc.data['content_warning'].to_s.strip
      end

      # Find summary
      #
      # @return [String,nil]
      def summary
        @summary ||=
          if content_warning.empty?
            doc.data.slice('title', 'summary').values.join(separator)
          else
            [content_warning, doc.data['title']].join(separator)
          end
      end

      # Should it have a content warning?
      def sensitive?
        !content_warning.empty? || !!doc.data.fetch('sensitive', false)
      end

      # Separator to join title and summary by
      #
      # @return [String]
      def separator
        @separator ||= site.config.dig('activity_pub', 'separator') || ' // '
      end

      # Find attachments
      #
      # @return [Array]
      def attachments
        @attachments ||= [].tap do |array|
          case (image = doc.data['image'])
          when Hash
            array << Document.new(site, image['path'], image['description'])
          when String
            array << Document.new(site, image, summary)
          end
        end
      end
    end
  end
end
